# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ContentService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_by': 'str',
        'created_on': 'Timestamp',
        'description': 'str',
        'id': 'str',
        'metadata': 'object',
        'name': 'str',
        'organization': 'Organization',
        'public_access': 'bool',
        'ref': 'str',
        'slug': 'str',
        'updated_by': 'str',
        'updated_on': 'Timestamp',
        'uuid': 'str'
    }

    attribute_map = {
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'description': 'description',
        'id': 'id',
        'metadata': 'metadata',
        'name': 'name',
        'organization': 'organization',
        'public_access': 'publicAccess',
        'ref': 'ref',
        'slug': 'slug',
        'updated_by': 'updatedBy',
        'updated_on': 'updatedOn',
        'uuid': 'uuid'
    }

    def __init__(self, created_by=None, created_on=None, description=None, id=None, metadata=None, name=None, organization=None, public_access=None, ref=None, slug=None, updated_by=None, updated_on=None, uuid=None):  # noqa: E501
        """ContentService - a model defined in Swagger"""  # noqa: E501
        self._created_by = None
        self._created_on = None
        self._description = None
        self._id = None
        self._metadata = None
        self._name = None
        self._organization = None
        self._public_access = None
        self._ref = None
        self._slug = None
        self._updated_by = None
        self._updated_on = None
        self._uuid = None
        self.discriminator = None
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if metadata is not None:
            self.metadata = metadata
        if name is not None:
            self.name = name
        if organization is not None:
            self.organization = organization
        if public_access is not None:
            self.public_access = public_access
        if ref is not None:
            self.ref = ref
        if slug is not None:
            self.slug = slug
        if updated_by is not None:
            self.updated_by = updated_by
        if updated_on is not None:
            self.updated_on = updated_on
        if uuid is not None:
            self.uuid = uuid

    @property
    def created_by(self):
        """Gets the created_by of this ContentService.  # noqa: E501


        :return: The created_by of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ContentService.


        :param created_by: The created_by of this ContentService.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this ContentService.  # noqa: E501


        :return: The created_on of this ContentService.  # noqa: E501
        :rtype: Timestamp
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ContentService.


        :param created_on: The created_on of this ContentService.  # noqa: E501
        :type: Timestamp
        """

        self._created_on = created_on

    @property
    def description(self):
        """Gets the description of this ContentService.  # noqa: E501


        :return: The description of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ContentService.


        :param description: The description of this ContentService.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this ContentService.  # noqa: E501


        :return: The id of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ContentService.


        :param id: The id of this ContentService.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def metadata(self):
        """Gets the metadata of this ContentService.  # noqa: E501


        :return: The metadata of this ContentService.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ContentService.


        :param metadata: The metadata of this ContentService.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def name(self):
        """Gets the name of this ContentService.  # noqa: E501


        :return: The name of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ContentService.


        :param name: The name of this ContentService.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def organization(self):
        """Gets the organization of this ContentService.  # noqa: E501


        :return: The organization of this ContentService.  # noqa: E501
        :rtype: Organization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this ContentService.


        :param organization: The organization of this ContentService.  # noqa: E501
        :type: Organization
        """

        self._organization = organization

    @property
    def public_access(self):
        """Gets the public_access of this ContentService.  # noqa: E501


        :return: The public_access of this ContentService.  # noqa: E501
        :rtype: bool
        """
        return self._public_access

    @public_access.setter
    def public_access(self, public_access):
        """Sets the public_access of this ContentService.


        :param public_access: The public_access of this ContentService.  # noqa: E501
        :type: bool
        """

        self._public_access = public_access

    @property
    def ref(self):
        """Gets the ref of this ContentService.  # noqa: E501


        :return: The ref of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._ref

    @ref.setter
    def ref(self, ref):
        """Sets the ref of this ContentService.


        :param ref: The ref of this ContentService.  # noqa: E501
        :type: str
        """

        self._ref = ref

    @property
    def slug(self):
        """Gets the slug of this ContentService.  # noqa: E501


        :return: The slug of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this ContentService.


        :param slug: The slug of this ContentService.  # noqa: E501
        :type: str
        """

        self._slug = slug

    @property
    def updated_by(self):
        """Gets the updated_by of this ContentService.  # noqa: E501


        :return: The updated_by of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this ContentService.


        :param updated_by: The updated_by of this ContentService.  # noqa: E501
        :type: str
        """

        self._updated_by = updated_by

    @property
    def updated_on(self):
        """Gets the updated_on of this ContentService.  # noqa: E501


        :return: The updated_on of this ContentService.  # noqa: E501
        :rtype: Timestamp
        """
        return self._updated_on

    @updated_on.setter
    def updated_on(self, updated_on):
        """Sets the updated_on of this ContentService.


        :param updated_on: The updated_on of this ContentService.  # noqa: E501
        :type: Timestamp
        """

        self._updated_on = updated_on

    @property
    def uuid(self):
        """Gets the uuid of this ContentService.  # noqa: E501


        :return: The uuid of this ContentService.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this ContentService.


        :param uuid: The uuid of this ContentService.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ContentService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContentService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from kodexa_cloud.api.access_token_controller_api import AccessTokenControllerApi
from kodexa_cloud.api.account_controller_api import AccountControllerApi
from kodexa_cloud.api.basic_error_controller_api import BasicErrorControllerApi
from kodexa_cloud.api.bot_controller_api import BotControllerApi
from kodexa_cloud.api.cloud_session_controller_api import CloudSessionControllerApi
from kodexa_cloud.api.content_service_controller_api import ContentServiceControllerApi
from kodexa_cloud.api.content_service_version_controller_api import ContentServiceVersionControllerApi
from kodexa_cloud.api.content_services_endpoint_controller_api import ContentServicesEndpointControllerApi
from kodexa_cloud.api.deployment_controller_api import DeploymentControllerApi
from kodexa_cloud.api.email_subscriber_controller_api import EmailSubscriberControllerApi
from kodexa_cloud.api.feedback_controller_api import FeedbackControllerApi
from kodexa_cloud.api.membership_controller_api import MembershipControllerApi
from kodexa_cloud.api.organization_controller_api import OrganizationControllerApi
from kodexa_cloud.api.pipeline_controller_api import PipelineControllerApi
from kodexa_cloud.api.platform_controller_api import PlatformControllerApi
from kodexa_cloud.api.platform_user_controller_api import PlatformUserControllerApi
from kodexa_cloud.api.service_request_controller_api import ServiceRequestControllerApi



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class GraphCell(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'options': 'object',
        'post': 'list[CellProcessor]',
        'pre': 'list[CellProcessor]',
        'ref': 'str',
        'type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'options': 'options',
        'post': 'post',
        'pre': 'pre',
        'ref': 'ref',
        'type': 'type'
    }

    def __init__(self, id=None, options=None, post=None, pre=None, ref=None, type=None):  # noqa: E501
        """GraphCell - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._options = None
        self._post = None
        self._pre = None
        self._ref = None
        self._type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if options is not None:
            self.options = options
        if post is not None:
            self.post = post
        if pre is not None:
            self.pre = pre
        if ref is not None:
            self.ref = ref
        if type is not None:
            self.type = type

    @property
    def id(self):
        """Gets the id of this GraphCell.  # noqa: E501


        :return: The id of this GraphCell.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GraphCell.


        :param id: The id of this GraphCell.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def options(self):
        """Gets the options of this GraphCell.  # noqa: E501


        :return: The options of this GraphCell.  # noqa: E501
        :rtype: object
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this GraphCell.


        :param options: The options of this GraphCell.  # noqa: E501
        :type: object
        """

        self._options = options

    @property
    def post(self):
        """Gets the post of this GraphCell.  # noqa: E501


        :return: The post of this GraphCell.  # noqa: E501
        :rtype: list[CellProcessor]
        """
        return self._post

    @post.setter
    def post(self, post):
        """Sets the post of this GraphCell.


        :param post: The post of this GraphCell.  # noqa: E501
        :type: list[CellProcessor]
        """

        self._post = post

    @property
    def pre(self):
        """Gets the pre of this GraphCell.  # noqa: E501


        :return: The pre of this GraphCell.  # noqa: E501
        :rtype: list[CellProcessor]
        """
        return self._pre

    @pre.setter
    def pre(self, pre):
        """Sets the pre of this GraphCell.


        :param pre: The pre of this GraphCell.  # noqa: E501
        :type: list[CellProcessor]
        """

        self._pre = pre

    @property
    def ref(self):
        """Gets the ref of this GraphCell.  # noqa: E501


        :return: The ref of this GraphCell.  # noqa: E501
        :rtype: str
        """
        return self._ref

    @ref.setter
    def ref(self, ref):
        """Sets the ref of this GraphCell.


        :param ref: The ref of this GraphCell.  # noqa: E501
        :type: str
        """

        self._ref = ref

    @property
    def type(self):
        """Gets the type of this GraphCell.  # noqa: E501


        :return: The type of this GraphCell.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GraphCell.


        :param type: The type of this GraphCell.  # noqa: E501
        :type: str
        """
        allowed_values = ["PIPELINE", "ACTION", "DECISION"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GraphCell, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GraphCell):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ExceptionDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error_message': 'str',
        'error_type': 'str',
        'executed_version': 'str',
        'help': 'str',
        'message': 'str',
        'stack_trace': 'list[object]',
        'status_code': 'int'
    }

    attribute_map = {
        'error_message': 'errorMessage',
        'error_type': 'errorType',
        'executed_version': 'executedVersion',
        'help': 'help',
        'message': 'message',
        'stack_trace': 'stackTrace',
        'status_code': 'statusCode'
    }

    def __init__(self, error_message=None, error_type=None, executed_version=None, help=None, message=None, stack_trace=None, status_code=None):  # noqa: E501
        """ExceptionDetails - a model defined in Swagger"""  # noqa: E501
        self._error_message = None
        self._error_type = None
        self._executed_version = None
        self._help = None
        self._message = None
        self._stack_trace = None
        self._status_code = None
        self.discriminator = None
        if error_message is not None:
            self.error_message = error_message
        if error_type is not None:
            self.error_type = error_type
        if executed_version is not None:
            self.executed_version = executed_version
        if help is not None:
            self.help = help
        if message is not None:
            self.message = message
        if stack_trace is not None:
            self.stack_trace = stack_trace
        if status_code is not None:
            self.status_code = status_code

    @property
    def error_message(self):
        """Gets the error_message of this ExceptionDetails.  # noqa: E501


        :return: The error_message of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this ExceptionDetails.


        :param error_message: The error_message of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def error_type(self):
        """Gets the error_type of this ExceptionDetails.  # noqa: E501


        :return: The error_type of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """Sets the error_type of this ExceptionDetails.


        :param error_type: The error_type of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._error_type = error_type

    @property
    def executed_version(self):
        """Gets the executed_version of this ExceptionDetails.  # noqa: E501


        :return: The executed_version of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._executed_version

    @executed_version.setter
    def executed_version(self, executed_version):
        """Sets the executed_version of this ExceptionDetails.


        :param executed_version: The executed_version of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._executed_version = executed_version

    @property
    def help(self):
        """Gets the help of this ExceptionDetails.  # noqa: E501


        :return: The help of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._help

    @help.setter
    def help(self, help):
        """Sets the help of this ExceptionDetails.


        :param help: The help of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._help = help

    @property
    def message(self):
        """Gets the message of this ExceptionDetails.  # noqa: E501


        :return: The message of this ExceptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ExceptionDetails.


        :param message: The message of this ExceptionDetails.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def stack_trace(self):
        """Gets the stack_trace of this ExceptionDetails.  # noqa: E501


        :return: The stack_trace of this ExceptionDetails.  # noqa: E501
        :rtype: list[object]
        """
        return self._stack_trace

    @stack_trace.setter
    def stack_trace(self, stack_trace):
        """Sets the stack_trace of this ExceptionDetails.


        :param stack_trace: The stack_trace of this ExceptionDetails.  # noqa: E501
        :type: list[object]
        """

        self._stack_trace = stack_trace

    @property
    def status_code(self):
        """Gets the status_code of this ExceptionDetails.  # noqa: E501


        :return: The status_code of this ExceptionDetails.  # noqa: E501
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ExceptionDetails.


        :param status_code: The status_code of this ExceptionDetails.  # noqa: E501
        :type: int
        """

        self._status_code = status_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExceptionDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExceptionDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kodexa_cloud.api_client import ApiClient


class EmailSubscriberControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_using_post(self, **kwargs):  # noqa: E501
        """add  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str created_by:
        :param int created_on_date:
        :param int created_on_day:
        :param int created_on_hours:
        :param int created_on_minutes:
        :param int created_on_month:
        :param int created_on_nanos:
        :param int created_on_seconds:
        :param int created_on_time:
        :param int created_on_timezone_offset:
        :param int created_on_year:
        :param str email:
        :param str id:
        :param str updated_by:
        :param int updated_on_date:
        :param int updated_on_day:
        :param int updated_on_hours:
        :param int updated_on_minutes:
        :param int updated_on_month:
        :param int updated_on_nanos:
        :param int updated_on_seconds:
        :param int updated_on_time:
        :param int updated_on_timezone_offset:
        :param int updated_on_year:
        :param str uuid:
        :return: SubscriptionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """add  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str created_by:
        :param int created_on_date:
        :param int created_on_day:
        :param int created_on_hours:
        :param int created_on_minutes:
        :param int created_on_month:
        :param int created_on_nanos:
        :param int created_on_seconds:
        :param int created_on_time:
        :param int created_on_timezone_offset:
        :param int created_on_year:
        :param str email:
        :param str id:
        :param str updated_by:
        :param int updated_on_date:
        :param int updated_on_day:
        :param int updated_on_hours:
        :param int updated_on_minutes:
        :param int updated_on_month:
        :param int updated_on_nanos:
        :param int updated_on_seconds:
        :param int updated_on_time:
        :param int updated_on_timezone_offset:
        :param int updated_on_year:
        :param str uuid:
        :return: SubscriptionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['created_by', 'created_on_date', 'created_on_day', 'created_on_hours', 'created_on_minutes', 'created_on_month', 'created_on_nanos', 'created_on_seconds', 'created_on_time', 'created_on_timezone_offset', 'created_on_year', 'email', 'id', 'updated_by', 'updated_on_date', 'updated_on_day', 'updated_on_hours', 'updated_on_minutes', 'updated_on_month', 'updated_on_nanos', 'updated_on_seconds', 'updated_on_time', 'updated_on_timezone_offset', 'updated_on_year', 'uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'created_by' in params:
            query_params.append(('createdBy', params['created_by']))  # noqa: E501
        if 'created_on_date' in params:
            query_params.append(('createdOn.date', params['created_on_date']))  # noqa: E501
        if 'created_on_day' in params:
            query_params.append(('createdOn.day', params['created_on_day']))  # noqa: E501
        if 'created_on_hours' in params:
            query_params.append(('createdOn.hours', params['created_on_hours']))  # noqa: E501
        if 'created_on_minutes' in params:
            query_params.append(('createdOn.minutes', params['created_on_minutes']))  # noqa: E501
        if 'created_on_month' in params:
            query_params.append(('createdOn.month', params['created_on_month']))  # noqa: E501
        if 'created_on_nanos' in params:
            query_params.append(('createdOn.nanos', params['created_on_nanos']))  # noqa: E501
        if 'created_on_seconds' in params:
            query_params.append(('createdOn.seconds', params['created_on_seconds']))  # noqa: E501
        if 'created_on_time' in params:
            query_params.append(('createdOn.time', params['created_on_time']))  # noqa: E501
        if 'created_on_timezone_offset' in params:
            query_params.append(('createdOn.timezoneOffset', params['created_on_timezone_offset']))  # noqa: E501
        if 'created_on_year' in params:
            query_params.append(('createdOn.year', params['created_on_year']))  # noqa: E501
        if 'email' in params:
            query_params.append(('email', params['email']))  # noqa: E501
        if 'id' in params:
            query_params.append(('id', params['id']))  # noqa: E501
        if 'updated_by' in params:
            query_params.append(('updatedBy', params['updated_by']))  # noqa: E501
        if 'updated_on_date' in params:
            query_params.append(('updatedOn.date', params['updated_on_date']))  # noqa: E501
        if 'updated_on_day' in params:
            query_params.append(('updatedOn.day', params['updated_on_day']))  # noqa: E501
        if 'updated_on_hours' in params:
            query_params.append(('updatedOn.hours', params['updated_on_hours']))  # noqa: E501
        if 'updated_on_minutes' in params:
            query_params.append(('updatedOn.minutes', params['updated_on_minutes']))  # noqa: E501
        if 'updated_on_month' in params:
            query_params.append(('updatedOn.month', params['updated_on_month']))  # noqa: E501
        if 'updated_on_nanos' in params:
            query_params.append(('updatedOn.nanos', params['updated_on_nanos']))  # noqa: E501
        if 'updated_on_seconds' in params:
            query_params.append(('updatedOn.seconds', params['updated_on_seconds']))  # noqa: E501
        if 'updated_on_time' in params:
            query_params.append(('updatedOn.time', params['updated_on_time']))  # noqa: E501
        if 'updated_on_timezone_offset' in params:
            query_params.append(('updatedOn.timezoneOffset', params['updated_on_timezone_offset']))  # noqa: E501
        if 'updated_on_year' in params:
            query_params.append(('updatedOn.year', params['updated_on_year']))  # noqa: E501
        if 'uuid' in params:
            query_params.append(('uuid', params['uuid']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/emailSubscriber', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubscriptionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CloudExecution(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'context': 'object',
        'custom_options': 'object',
        'document_references': 'list[CloudDocumentReference]',
        'end': 'datetime',
        'exception_details': 'ExceptionDetails',
        'file_references': 'list[CloudFileReference]',
        'id': 'str',
        'number_of_steps': 'int',
        'pipeline_template_id': 'str',
        'processing_time': 'int',
        'session_id': 'str',
        'start': 'datetime',
        'status': 'str',
        'steps': 'list[CloudExecutionStep]',
        'steps_completed': 'int',
        'stores': 'list[CloudStore]'
    }

    attribute_map = {
        'context': 'context',
        'custom_options': 'customOptions',
        'document_references': 'documentReferences',
        'end': 'end',
        'exception_details': 'exceptionDetails',
        'file_references': 'fileReferences',
        'id': 'id',
        'number_of_steps': 'numberOfSteps',
        'pipeline_template_id': 'pipelineTemplateId',
        'processing_time': 'processingTime',
        'session_id': 'sessionId',
        'start': 'start',
        'status': 'status',
        'steps': 'steps',
        'steps_completed': 'stepsCompleted',
        'stores': 'stores'
    }

    def __init__(self, context=None, custom_options=None, document_references=None, end=None, exception_details=None, file_references=None, id=None, number_of_steps=None, pipeline_template_id=None, processing_time=None, session_id=None, start=None, status=None, steps=None, steps_completed=None, stores=None):  # noqa: E501
        """CloudExecution - a model defined in Swagger"""  # noqa: E501
        self._context = None
        self._custom_options = None
        self._document_references = None
        self._end = None
        self._exception_details = None
        self._file_references = None
        self._id = None
        self._number_of_steps = None
        self._pipeline_template_id = None
        self._processing_time = None
        self._session_id = None
        self._start = None
        self._status = None
        self._steps = None
        self._steps_completed = None
        self._stores = None
        self.discriminator = None
        if context is not None:
            self.context = context
        if custom_options is not None:
            self.custom_options = custom_options
        if document_references is not None:
            self.document_references = document_references
        if end is not None:
            self.end = end
        if exception_details is not None:
            self.exception_details = exception_details
        if file_references is not None:
            self.file_references = file_references
        if id is not None:
            self.id = id
        if number_of_steps is not None:
            self.number_of_steps = number_of_steps
        if pipeline_template_id is not None:
            self.pipeline_template_id = pipeline_template_id
        if processing_time is not None:
            self.processing_time = processing_time
        if session_id is not None:
            self.session_id = session_id
        if start is not None:
            self.start = start
        if status is not None:
            self.status = status
        if steps is not None:
            self.steps = steps
        if steps_completed is not None:
            self.steps_completed = steps_completed
        if stores is not None:
            self.stores = stores

    @property
    def context(self):
        """Gets the context of this CloudExecution.  # noqa: E501


        :return: The context of this CloudExecution.  # noqa: E501
        :rtype: object
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this CloudExecution.


        :param context: The context of this CloudExecution.  # noqa: E501
        :type: object
        """

        self._context = context

    @property
    def custom_options(self):
        """Gets the custom_options of this CloudExecution.  # noqa: E501


        :return: The custom_options of this CloudExecution.  # noqa: E501
        :rtype: object
        """
        return self._custom_options

    @custom_options.setter
    def custom_options(self, custom_options):
        """Sets the custom_options of this CloudExecution.


        :param custom_options: The custom_options of this CloudExecution.  # noqa: E501
        :type: object
        """

        self._custom_options = custom_options

    @property
    def document_references(self):
        """Gets the document_references of this CloudExecution.  # noqa: E501


        :return: The document_references of this CloudExecution.  # noqa: E501
        :rtype: list[CloudDocumentReference]
        """
        return self._document_references

    @document_references.setter
    def document_references(self, document_references):
        """Sets the document_references of this CloudExecution.


        :param document_references: The document_references of this CloudExecution.  # noqa: E501
        :type: list[CloudDocumentReference]
        """

        self._document_references = document_references

    @property
    def end(self):
        """Gets the end of this CloudExecution.  # noqa: E501


        :return: The end of this CloudExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this CloudExecution.


        :param end: The end of this CloudExecution.  # noqa: E501
        :type: datetime
        """

        self._end = end

    @property
    def exception_details(self):
        """Gets the exception_details of this CloudExecution.  # noqa: E501


        :return: The exception_details of this CloudExecution.  # noqa: E501
        :rtype: ExceptionDetails
        """
        return self._exception_details

    @exception_details.setter
    def exception_details(self, exception_details):
        """Sets the exception_details of this CloudExecution.


        :param exception_details: The exception_details of this CloudExecution.  # noqa: E501
        :type: ExceptionDetails
        """

        self._exception_details = exception_details

    @property
    def file_references(self):
        """Gets the file_references of this CloudExecution.  # noqa: E501


        :return: The file_references of this CloudExecution.  # noqa: E501
        :rtype: list[CloudFileReference]
        """
        return self._file_references

    @file_references.setter
    def file_references(self, file_references):
        """Sets the file_references of this CloudExecution.


        :param file_references: The file_references of this CloudExecution.  # noqa: E501
        :type: list[CloudFileReference]
        """

        self._file_references = file_references

    @property
    def id(self):
        """Gets the id of this CloudExecution.  # noqa: E501


        :return: The id of this CloudExecution.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudExecution.


        :param id: The id of this CloudExecution.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def number_of_steps(self):
        """Gets the number_of_steps of this CloudExecution.  # noqa: E501


        :return: The number_of_steps of this CloudExecution.  # noqa: E501
        :rtype: int
        """
        return self._number_of_steps

    @number_of_steps.setter
    def number_of_steps(self, number_of_steps):
        """Sets the number_of_steps of this CloudExecution.


        :param number_of_steps: The number_of_steps of this CloudExecution.  # noqa: E501
        :type: int
        """

        self._number_of_steps = number_of_steps

    @property
    def pipeline_template_id(self):
        """Gets the pipeline_template_id of this CloudExecution.  # noqa: E501


        :return: The pipeline_template_id of this CloudExecution.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_template_id

    @pipeline_template_id.setter
    def pipeline_template_id(self, pipeline_template_id):
        """Sets the pipeline_template_id of this CloudExecution.


        :param pipeline_template_id: The pipeline_template_id of this CloudExecution.  # noqa: E501
        :type: str
        """

        self._pipeline_template_id = pipeline_template_id

    @property
    def processing_time(self):
        """Gets the processing_time of this CloudExecution.  # noqa: E501


        :return: The processing_time of this CloudExecution.  # noqa: E501
        :rtype: int
        """
        return self._processing_time

    @processing_time.setter
    def processing_time(self, processing_time):
        """Sets the processing_time of this CloudExecution.


        :param processing_time: The processing_time of this CloudExecution.  # noqa: E501
        :type: int
        """

        self._processing_time = processing_time

    @property
    def session_id(self):
        """Gets the session_id of this CloudExecution.  # noqa: E501


        :return: The session_id of this CloudExecution.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this CloudExecution.


        :param session_id: The session_id of this CloudExecution.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def start(self):
        """Gets the start of this CloudExecution.  # noqa: E501


        :return: The start of this CloudExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this CloudExecution.


        :param start: The start of this CloudExecution.  # noqa: E501
        :type: datetime
        """

        self._start = start

    @property
    def status(self):
        """Gets the status of this CloudExecution.  # noqa: E501


        :return: The status of this CloudExecution.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CloudExecution.


        :param status: The status of this CloudExecution.  # noqa: E501
        :type: str
        """
        allowed_values = ["PENDING", "RUNNING", "SUCCEEDED", "FAILED", "REQUESTED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def steps(self):
        """Gets the steps of this CloudExecution.  # noqa: E501


        :return: The steps of this CloudExecution.  # noqa: E501
        :rtype: list[CloudExecutionStep]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this CloudExecution.


        :param steps: The steps of this CloudExecution.  # noqa: E501
        :type: list[CloudExecutionStep]
        """

        self._steps = steps

    @property
    def steps_completed(self):
        """Gets the steps_completed of this CloudExecution.  # noqa: E501


        :return: The steps_completed of this CloudExecution.  # noqa: E501
        :rtype: int
        """
        return self._steps_completed

    @steps_completed.setter
    def steps_completed(self, steps_completed):
        """Sets the steps_completed of this CloudExecution.


        :param steps_completed: The steps_completed of this CloudExecution.  # noqa: E501
        :type: int
        """

        self._steps_completed = steps_completed

    @property
    def stores(self):
        """Gets the stores of this CloudExecution.  # noqa: E501


        :return: The stores of this CloudExecution.  # noqa: E501
        :rtype: list[CloudStore]
        """
        return self._stores

    @stores.setter
    def stores(self, stores):
        """Sets the stores of this CloudExecution.


        :param stores: The stores of this CloudExecution.  # noqa: E501
        :type: list[CloudStore]
        """

        self._stores = stores

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CloudExecution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudExecution):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kodexa_cloud.api_client import ApiClient


class OrganizationControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_using_post6(self, body, **kwargs):  # noqa: E501
        """Create a new instance of the resource  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_using_post6(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Organization body: entity (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_using_post6_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_using_post6_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_using_post6_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a new instance of the resource  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_using_post6_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Organization body: entity (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_using_post6" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_using_post6`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/organizations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_using_delete6(self, id, **kwargs):  # noqa: E501
        """Delete the resource with the provided ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_using_delete6(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_using_delete6_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_using_delete6_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_using_delete6_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete the resource with the provided ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_using_delete6_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_using_delete6" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_using_delete6`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/organizations/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_organization_dash_board_using_get(self, organization_id, **kwargs):  # noqa: E501
        """getOrganizationDashBoard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_organization_dash_board_using_get(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: organizationId (required)
        :return: OrganizationDashboard
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_organization_dash_board_using_get_with_http_info(organization_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_organization_dash_board_using_get_with_http_info(organization_id, **kwargs)  # noqa: E501
            return data

    def get_organization_dash_board_using_get_with_http_info(self, organization_id, **kwargs):  # noqa: E501
        """getOrganizationDashBoard  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_organization_dash_board_using_get_with_http_info(organization_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_id: organizationId (required)
        :return: OrganizationDashboard
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organization_dash_board_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_id' is set
        if ('organization_id' not in params or
                params['organization_id'] is None):
            raise ValueError("Missing the required parameter `organization_id` when calling `get_organization_dash_board_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_id' in params:
            path_params['organizationId'] = params['organization_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/organizations/{organizationId}/dashboard', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OrganizationDashboard',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_using_get6(self, id, **kwargs):  # noqa: E501
        """Get a resource with the provided ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_using_get6(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_using_get6_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_using_get6_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_using_get6_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get a resource with the provided ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_using_get6_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_using_get6" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_using_get6`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/organizations/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_using_get6(self, **kwargs):  # noqa: E501
        """List a page of the resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_using_get6(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PageOfOrganization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_using_get6_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_using_get6_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_using_get6_with_http_info(self, **kwargs):  # noqa: E501
        """List a page of the resources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_using_get6_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PageOfOrganization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_using_get6" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/organizations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageOfOrganization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_using_put6(self, body, id, **kwargs):  # noqa: E501
        """Update the given instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_using_put6(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Organization body: entity (required)
        :param str id: id (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_using_put6_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_using_put6_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def update_using_put6_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Update the given instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_using_put6_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Organization body: entity (required)
        :param str id: id (required)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_using_put6" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_using_put6`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_using_put6`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/organizations/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Organization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from kodexa_cloud.api.access_token_controller_api import AccessTokenControllerApi
from kodexa_cloud.api.account_controller_api import AccountControllerApi
from kodexa_cloud.api.basic_error_controller_api import BasicErrorControllerApi
from kodexa_cloud.api.bot_controller_api import BotControllerApi
from kodexa_cloud.api.cloud_session_controller_api import CloudSessionControllerApi
from kodexa_cloud.api.content_service_controller_api import ContentServiceControllerApi
from kodexa_cloud.api.content_service_version_controller_api import ContentServiceVersionControllerApi
from kodexa_cloud.api.content_services_endpoint_controller_api import ContentServicesEndpointControllerApi
from kodexa_cloud.api.deployment_controller_api import DeploymentControllerApi
from kodexa_cloud.api.email_subscriber_controller_api import EmailSubscriberControllerApi
from kodexa_cloud.api.feedback_controller_api import FeedbackControllerApi
from kodexa_cloud.api.membership_controller_api import MembershipControllerApi
from kodexa_cloud.api.organization_controller_api import OrganizationControllerApi
from kodexa_cloud.api.pipeline_controller_api import PipelineControllerApi
from kodexa_cloud.api.platform_controller_api import PlatformControllerApi
from kodexa_cloud.api.platform_user_controller_api import PlatformUserControllerApi
from kodexa_cloud.api.service_request_controller_api import ServiceRequestControllerApi
# import ApiClient
from kodexa_cloud.api_client import ApiClient
from kodexa_cloud.configuration import Configuration
# import models into sdk package
from kodexa_cloud.models.access_token import AccessToken
from kodexa_cloud.models.bot import Bot
from kodexa_cloud.models.bot_event_trigger import BotEventTrigger
from kodexa_cloud.models.bot_metadata import BotMetadata
from kodexa_cloud.models.byte_array_resource import ByteArrayResource
from kodexa_cloud.models.cell_processor import CellProcessor
from kodexa_cloud.models.cloud_bot_session import CloudBotSession
from kodexa_cloud.models.cloud_content_service_session import CloudContentServiceSession
from kodexa_cloud.models.cloud_document import CloudDocument
from kodexa_cloud.models.cloud_document_reference import CloudDocumentReference
from kodexa_cloud.models.cloud_execution import CloudExecution
from kodexa_cloud.models.cloud_execution_step import CloudExecutionStep
from kodexa_cloud.models.cloud_file import CloudFile
from kodexa_cloud.models.cloud_file_reference import CloudFileReference
from kodexa_cloud.models.cloud_pipeline import CloudPipeline
from kodexa_cloud.models.cloud_pipeline_session import CloudPipelineSession
from kodexa_cloud.models.cloud_session import CloudSession
from kodexa_cloud.models.cloud_store import CloudStore
from kodexa_cloud.models.content_service import ContentService
from kodexa_cloud.models.content_service_reference import ContentServiceReference
from kodexa_cloud.models.content_service_version import ContentServiceVersion
from kodexa_cloud.models.deployment import Deployment
from kodexa_cloud.models.deployment_metadata import DeploymentMetadata
from kodexa_cloud.models.email_deployment import EmailDeployment
from kodexa_cloud.models.email_lookup import EmailLookup
from kodexa_cloud.models.exception_details import ExceptionDetails
from kodexa_cloud.models.exception_report import ExceptionReport
from kodexa_cloud.models.feedback import Feedback
from kodexa_cloud.models.file import File
from kodexa_cloud.models.graph_cell import GraphCell
from kodexa_cloud.models.input_stream import InputStream
from kodexa_cloud.models.login_request import LoginRequest
from kodexa_cloud.models.membership import Membership
from kodexa_cloud.models.model_and_view import ModelAndView
from kodexa_cloud.models.organization import Organization
from kodexa_cloud.models.organization_dashboard import OrganizationDashboard
from kodexa_cloud.models.page_of_access_token import PageOfAccessToken
from kodexa_cloud.models.page_of_bot import PageOfBot
from kodexa_cloud.models.page_of_content_service import PageOfContentService
from kodexa_cloud.models.page_of_content_service_version import PageOfContentServiceVersion
from kodexa_cloud.models.page_of_deployment import PageOfDeployment
from kodexa_cloud.models.page_of_membership import PageOfMembership
from kodexa_cloud.models.page_of_organization import PageOfOrganization
from kodexa_cloud.models.page_of_pipeline import PageOfPipeline
from kodexa_cloud.models.page_of_platform_user import PageOfPlatformUser
from kodexa_cloud.models.page_of_service_request import PageOfServiceRequest
from kodexa_cloud.models.pageable import Pageable
from kodexa_cloud.models.password_change import PasswordChange
from kodexa_cloud.models.pipeline import Pipeline
from kodexa_cloud.models.pipeline_metadata import PipelineMetadata
from kodexa_cloud.models.pipeline_step_metadata import PipelineStepMetadata
from kodexa_cloud.models.platform_overview import PlatformOverview
from kodexa_cloud.models.platform_user import PlatformUser
from kodexa_cloud.models.register_user import RegisterUser
from kodexa_cloud.models.service_request import ServiceRequest
from kodexa_cloud.models.slack_deployment import SlackDeployment
from kodexa_cloud.models.sort import Sort
from kodexa_cloud.models.subscription_response import SubscriptionResponse
from kodexa_cloud.models.timestamp import Timestamp
from kodexa_cloud.models.uri import URI
from kodexa_cloud.models.url import URL
from kodexa_cloud.models.user_activation import UserActivation
from kodexa_cloud.models.view import View



# coding: utf-8

"""
    Kodexa

    Content Intelligence  # noqa: E501

    OpenAPI spec version: 2.0.132
    Contact: suppot@kodexa.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kodexa_cloud.api_client import ApiClient


class CloudSessionControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_pipeline_session_using_post(self, pipeline_id, **kwargs):  # noqa: E501
        """createPipelineSession  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_pipeline_session_using_post(pipeline_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pipeline_id: pipelineId (required)
        :param str x_access_token: x-access-token
        :return: CloudSession
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_pipeline_session_using_post_with_http_info(pipeline_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_pipeline_session_using_post_with_http_info(pipeline_id, **kwargs)  # noqa: E501
            return data

    def create_pipeline_session_using_post_with_http_info(self, pipeline_id, **kwargs):  # noqa: E501
        """createPipelineSession  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_pipeline_session_using_post_with_http_info(pipeline_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pipeline_id: pipelineId (required)
        :param str x_access_token: x-access-token
        :return: CloudSession
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pipeline_id', 'x_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_pipeline_session_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'pipeline_id' is set
        if ('pipeline_id' not in params or
                params['pipeline_id'] is None):
            raise ValueError("Missing the required parameter `pipeline_id` when calling `create_pipeline_session_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'pipeline_id' in params:
            query_params.append(('pipelineId', params['pipeline_id']))  # noqa: E501

        header_params = {}
        if 'x_access_token' in params:
            header_params['x-access-token'] = params['x_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/sessions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CloudSession',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_execution_document_using_get(self, document_id, execution_id, session_id, **kwargs):  # noqa: E501
        """getExecutionDocument  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_execution_document_using_get(document_id, execution_id, session_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str document_id: documentId (required)
        :param str execution_id: executionId (required)
        :param str session_id: sessionId (required)
        :param str x_access_token: x-access-token
        :return: ByteArrayResource
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_execution_document_using_get_with_http_info(document_id, execution_id, session_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_execution_document_using_get_with_http_info(document_id, execution_id, session_id, **kwargs)  # noqa: E501
            return data

    def get_execution_document_using_get_with_http_info(self, document_id, execution_id, session_id, **kwargs):  # noqa: E501
        """getExecutionDocument  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_execution_document_using_get_with_http_info(document_id, execution_id, session_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str document_id: documentId (required)
        :param str execution_id: executionId (required)
        :param str session_id: sessionId (required)
        :param str x_access_token: x-access-token
        :return: ByteArrayResource
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['document_id', 'execution_id', 'session_id', 'x_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_execution_document_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'document_id' is set
        if ('document_id' not in params or
                params['document_id'] is None):
            raise ValueError("Missing the required parameter `document_id` when calling `get_execution_document_using_get`")  # noqa: E501
        # verify the required parameter 'execution_id' is set
        if ('execution_id' not in params or
                params['execution_id'] is None):
            raise ValueError("Missing the required parameter `execution_id` when calling `get_execution_document_using_get`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if ('session_id' not in params or
                params['session_id'] is None):
            raise ValueError("Missing the required parameter `session_id` when calling `get_execution_document_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'document_id' in params:
            path_params['documentId'] = params['document_id']  # noqa: E501
        if 'execution_id' in params:
            path_params['executionId'] = params['execution_id']  # noqa: E501
        if 'session_id' in params:
            path_params['sessionId'] = params['session_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_access_token' in params:
            header_params['x-access-token'] = params['x_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/sessions/{sessionId}/executions/{executionId}/documents/{documentId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ByteArrayResource',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_execution_file_using_get(self, execution_id, file_id, session_id, **kwargs):  # noqa: E501
        """getExecutionFile  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_execution_file_using_get(execution_id, file_id, session_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str execution_id: executionId (required)
        :param str file_id: fileId (required)
        :param str session_id: sessionId (required)
        :param str x_access_token: x-access-token
        :return: ByteArrayResource
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_execution_file_using_get_with_http_info(execution_id, file_id, session_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_execution_file_using_get_with_http_info(execution_id, file_id, session_id, **kwargs)  # noqa: E501
            return data

    def get_execution_file_using_get_with_http_info(self, execution_id, file_id, session_id, **kwargs):  # noqa: E501
        """getExecutionFile  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_execution_file_using_get_with_http_info(execution_id, file_id, session_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str execution_id: executionId (required)
        :param str file_id: fileId (required)
        :param str session_id: sessionId (required)
        :param str x_access_token: x-access-token
        :return: ByteArrayResource
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['execution_id', 'file_id', 'session_id', 'x_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_execution_file_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'execution_id' is set
        if ('execution_id' not in params or
                params['execution_id'] is None):
            raise ValueError("Missing the required parameter `execution_id` when calling `get_execution_file_using_get`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `get_execution_file_using_get`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if ('session_id' not in params or
                params['session_id'] is None):
            raise ValueError("Missing the required parameter `session_id` when calling `get_execution_file_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'execution_id' in params:
            path_params['executionId'] = params['execution_id']  # noqa: E501
        if 'file_id' in params:
            path_params['fileId'] = params['file_id']  # noqa: E501
        if 'session_id' in params:
            path_params['sessionId'] = params['session_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_access_token' in params:
            header_params['x-access-token'] = params['x_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/sessions/{sessionId}/executions/{executionId}/files/{fileId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ByteArrayResource',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_execution_using_get(self, execution_id, id, **kwargs):  # noqa: E501
        """getExecution  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_execution_using_get(execution_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str execution_id: executionId (required)
        :param str id: id (required)
        :param str x_access_token: x-access-token
        :return: CloudExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_execution_using_get_with_http_info(execution_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_execution_using_get_with_http_info(execution_id, id, **kwargs)  # noqa: E501
            return data

    def get_execution_using_get_with_http_info(self, execution_id, id, **kwargs):  # noqa: E501
        """getExecution  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_execution_using_get_with_http_info(execution_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str execution_id: executionId (required)
        :param str id: id (required)
        :param str x_access_token: x-access-token
        :return: CloudExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['execution_id', 'id', 'x_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_execution_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'execution_id' is set
        if ('execution_id' not in params or
                params['execution_id'] is None):
            raise ValueError("Missing the required parameter `execution_id` when calling `get_execution_using_get`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_execution_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'execution_id' in params:
            path_params['executionId'] = params['execution_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_access_token' in params:
            header_params['x-access-token'] = params['x_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/sessions/{id}/executions/{executionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CloudExecution',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_store_content_using_get(self, execution_id, session_id, store_id, **kwargs):  # noqa: E501
        """getStoreContent  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_store_content_using_get(execution_id, session_id, store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str execution_id: executionId (required)
        :param str session_id: sessionId (required)
        :param str store_id: storeId (required)
        :param str x_access_token: x-access-token
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_store_content_using_get_with_http_info(execution_id, session_id, store_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_store_content_using_get_with_http_info(execution_id, session_id, store_id, **kwargs)  # noqa: E501
            return data

    def get_store_content_using_get_with_http_info(self, execution_id, session_id, store_id, **kwargs):  # noqa: E501
        """getStoreContent  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_store_content_using_get_with_http_info(execution_id, session_id, store_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str execution_id: executionId (required)
        :param str session_id: sessionId (required)
        :param str store_id: storeId (required)
        :param str x_access_token: x-access-token
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['execution_id', 'session_id', 'store_id', 'x_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_store_content_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'execution_id' is set
        if ('execution_id' not in params or
                params['execution_id'] is None):
            raise ValueError("Missing the required parameter `execution_id` when calling `get_store_content_using_get`")  # noqa: E501
        # verify the required parameter 'session_id' is set
        if ('session_id' not in params or
                params['session_id'] is None):
            raise ValueError("Missing the required parameter `session_id` when calling `get_store_content_using_get`")  # noqa: E501
        # verify the required parameter 'store_id' is set
        if ('store_id' not in params or
                params['store_id'] is None):
            raise ValueError("Missing the required parameter `store_id` when calling `get_store_content_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'execution_id' in params:
            path_params['executionId'] = params['execution_id']  # noqa: E501
        if 'session_id' in params:
            path_params['sessionId'] = params['session_id']  # noqa: E501
        if 'store_id' in params:
            path_params['storeId'] = params['store_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_access_token' in params:
            header_params['x-access-token'] = params['x_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/sessions/{sessionId}/executions/{executionId}/stores/{storeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_sessions_using_get(self, **kwargs):  # noqa: E501
        """listSessions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_sessions_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_access_token: x-access-token
        :return: list[CloudSession]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_sessions_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_sessions_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_sessions_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """listSessions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_sessions_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_access_token: x-access-token
        :return: list[CloudSession]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_sessions_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_access_token' in params:
            header_params['x-access-token'] = params['x_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/sessions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CloudSession]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_execution_using_post(self, id, **kwargs):  # noqa: E501
        """startExecution  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_execution_using_post(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :param str document:
        :param str file:
        :param str x_access_token: x-access-token
        :param str options: options
        :return: CloudExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_execution_using_post_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.start_execution_using_post_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def start_execution_using_post_with_http_info(self, id, **kwargs):  # noqa: E501
        """startExecution  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_execution_using_post_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :param str document:
        :param str file:
        :param str x_access_token: x-access-token
        :param str options: options
        :return: CloudExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'document', 'file', 'x_access_token', 'options']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_execution_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `start_execution_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'options' in params:
            query_params.append(('options', params['options']))  # noqa: E501

        header_params = {}
        if 'x_access_token' in params:
            header_params['x-access-token'] = params['x_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'document' in params:
            local_var_files['document'] = params['document']  # noqa: E501
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/sessions/{id}/execute', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CloudExecution',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
